==> apache-wicket-7.18.0.zip: apache-wicket-7.18.0/wicket-experimental/wicket-metrics/src/main/java/org/apache/wicket/metrics/WicketMetricsSettings.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.metrics;

import com.codahale.metrics.JmxReporter;
import com.codahale.metrics.MetricRegistry;

/**
 * Settings to configure wicket metrics
 * 
 * @author Tobias Soloschenko
 *
 */
public class WicketMetricsSettings
{

	private boolean enabled = true;

	private String prefix = "application/";

	/**
	 * If the metrics should be enabled
	 * 
	 * @param enabled
	 *            if the metrics should be enabled
	 */
	public void setEnabled(boolean enabled)
	{
		this.enabled = enabled;
	}

	/**
	 * If the wicket metrics are enabled
	 * 
	 * @return if the wicket metrics are enabled
	 */
	public boolean isEnabled()
	{
		return enabled;
	}

	/**
	 * Gets the prefix.
	 * 
	 * @return the prefix
	 */
	public String getPrefix()
	{
		return prefix;
	}

	/**
	 * Sets the prefix to be used for the statistics
	 * 
	 * @param prefix
	 *            the prefix to be used
	 */
	public void setPrefix(String prefix)
	{
		if (!prefix.endsWith("/"))
		{
			prefix = prefix + "/";
		}
		this.prefix = prefix;
	}

	/**
	 * Starts the jmx reporter
	 */
	public void startJmxReporter()
	{
		MetricRegistry metricRegistry = WicketMetrics.getMetricRegistry();
		JmxReporter.forRegistry(metricRegistry).build().start();
	}

	/**
	 * Stops the jmx reporter
	 */
	public void stopJmxReporter()
	{
		MetricRegistry metricRegistry = WicketMetrics.getMetricRegistry();
		JmxReporter.forRegistry(metricRegistry).build().stop();
	}
}

==> apache-wicket-10.8.0.zip: apache-wicket-10.8.0/wicket-experimental/wicket-metrics/src/main/java/org/apache/wicket/metrics/WicketMetricsSettings.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.metrics;

import com.codahale.metrics.MetricRegistry;
import com.codahale.metrics.jmx.JmxReporter;

/**
 * Settings to configure wicket metrics
 * 
 * @author Tobias Soloschenko
 *
 */
public class WicketMetricsSettings
{

	private boolean enabled = true;

	private String prefix = "application/";

	/**
	 * If the metrics should be enabled
	 * 
	 * @param enabled
	 *            if the metrics should be enabled
	 */
	public void setEnabled(boolean enabled)
	{
		this.enabled = enabled;
	}

	/**
	 * If the wicket metrics are enabled
	 * 
	 * @return if the wicket metrics are enabled
	 */
	public boolean isEnabled()
	{
		return enabled;
	}

	/**
	 * Gets the prefix.
	 * 
	 * @return the prefix
	 */
	public String getPrefix()
	{
		return prefix;
	}

	/**
	 * Sets the prefix to be used for the statistics
	 * 
	 * @param prefix
	 *            the prefix to be used
	 */
	public void setPrefix(String prefix)
	{
		if (!prefix.endsWith("/"))
		{
			prefix = prefix + "/";
		}
		this.prefix = prefix;
	}

	/**
	 * Starts the jmx reporter
	 */
	public void startJmxReporter()
	{
		MetricRegistry metricRegistry = WicketMetrics.getMetricRegistry();
		JmxReporter.forRegistry(metricRegistry).build().start();
	}

	/**
	 * Stops the jmx reporter
	 */
	public void stopJmxReporter()
	{
		MetricRegistry metricRegistry = WicketMetrics.getMetricRegistry();
		JmxReporter.forRegistry(metricRegistry).build().stop();
	}
}
